SkipTestResult

Enum SkipTestResult 

#[repr(i32)]
pub enum SkipTestResult { CyclicTypeFunction = 0, Irreducible = 1, Stuck = 2, Generic = 3, Defer = 4, Okay = 5, }

Variants



CyclicTypeFunction = 0

If a type function is cyclic, it cannot be reduced, but maybe we can make a guess and offer a suggested annotation to the user.



Irreducible = 1

Indicase that we will not be able to reduce this type function this time. Constraint resolution may cause this type function to become reducible later.



Stuck = 2

A type function that cannot be reduced any further because it has no valid reduction. eg add<number, string>



Generic = 3

Some type functions can operate on generic parameters



Defer = 4

We might be able to reduce this type function, but not yet.



Okay = 5

We can attempt to reduce this type function right now.

Implementations

Source

impl SkipTestResult

pub const CyclicTypeFunction: Self = Self::CyclicTypeFunction

pub const Irreducible: Self = Self::Irreducible

pub const Stuck: Self = Self::Stuck

pub const Generic: Self = Self::Generic

pub const Defer: Self = Self::Defer

pub const Okay: Self = Self::Okay