Module index_function_impl

Module index_function_impl 

C++ TypeFunctionReductionResult<TypeId> indexFunctionImpl( const std::vector<TypeId>& typeParams, const std::vector<TypePackId>& packParams, NotNull<TypeFunctionContext> ctx, bool isRaw) (BuiltinTypeFunctions.cpp:2077-2209). Shared implementation behind index and rawget.

Vocabulary note: indexee refers to the type that contains the properties, indexer refers to the type that is used to access indexee. index<Person, "name"> => Person is the indexee and "name" is the indexer.

Functions

index_function_impl