Source: Analysis/src/OverloadResolver.cpp:457-548 (hand-ported)
Test a single FunctionType against an argument list. Reduces type functions and does a proper arity check.
Source: Analysis/src/OverloadResolver.cpp:457-548 (hand-ported)
Test a single FunctionType against an argument list. Reduces type functions and does a proper arity check.