pub struct MagicFunction { /* private fields */ }Expand description
MagicFunction is an abstract base class in C++. In Rust, we model this as a struct containing function pointers (vtable) to allow custom typechecking logic for builtins.
Implementations
Sourceimpl MagicFunction
impl MagicFunction
pub fn type_check(&self, _context: &MagicFunctionTypeCheckContext) -> bool
Sourceimpl MagicFunction
impl MagicFunction
Sourcepub fn from_handlers(
handle_old_solver: fn(&mut TypeChecker, &Arc<Scope>, &AstExprCall, WithPredicate<TypePackId>) -> Option<WithPredicate<TypePackId>>,
infer: fn(&MagicFunctionCallContext) -> bool,
refine: fn(&MagicRefinementContext),
type_check: fn(&MagicFunctionTypeCheckContext) -> bool,
) -> Self
pub fn from_handlers( handle_old_solver: fn(&mut TypeChecker, &Arc<Scope>, &AstExprCall, WithPredicate<TypePackId>) -> Option<WithPredicate<TypePackId>>, infer: fn(&MagicFunctionCallContext) -> bool, refine: fn(&MagicRefinementContext), type_check: fn(&MagicFunctionTypeCheckContext) -> bool, ) -> Self
Build a MagicFunction vtable from its four handler function pointers.
This is the public analog of constructing a MagicFunction subclass
(e.g. the test-only MagicInstanceIsA) outside this crate, where the
fields are not directly accessible.