TypeField

Enum TypeField 

#[repr(i32)]
pub enum TypeField { Table = 0, Metatable = 1, LowerBound = 2, UpperBound = 3, IndexLookup = 4, IndexResult = 5, Negated = 6, Variadic = 7, }

Variants



Table = 0

The table of a metatable type.



Metatable = 1

The metatable of a type. This could be a metatable type, a primitive type, a class type, or perhaps even a string singleton type.



LowerBound = 2

The lower bound of this type, if one is present.



UpperBound = 3

The upper bound of this type, if present.



IndexLookup = 4

The index type.



IndexResult = 5

The indexer result type.



Negated = 6

The negated type, for negations.



Variadic = 7

The variadic type for a type pack.